@@ -12,6 +12,8 @@ except ImportError:
 import os
 import ConfigParser
 import time
+import getpass
+import socket
 
 
 def get_hostname(netloc):
@@ -69,6 +71,8 @@ class ConfigManager(object):
             'smtp_tls': False,
             'smtp_user': False,
             'smtp_password': False,
+            'smtp_default_from_email': '%s@%s' % (
+                getpass.getuser(), socket.getfqdn()),
             'data_path': '/var/db/trytond',
             'multi_server': False,
             'session_timeout': 600,
@@ -104,15 +108,17 @@ class ConfigManager(object):
 
     def update_etc(self, configfile=None):
         if configfile is None:
-            prefixdir = os.path.abspath(os.path.normpath(os.path.join(
-                os.path.dirname(sys.prefix), '..')))
-            configfile = os.path.join(prefixdir, 'etc', 'trytond.conf')
-            if not os.path.isfile(configfile):
-                configdir = os.path.abspath(os.path.normpath(os.path.join(
-                    os.path.dirname(__file__), '..')))
-                configfile = os.path.join(configdir, 'etc', 'trytond.conf')
-            if not os.path.isfile(configfile):
-                configfile = None
+            configfile = os.environ.get('TRYTOND_CONFIG')
+            if not configfile:
+                prefixdir = os.path.abspath(os.path.normpath(os.path.join(
+                    os.path.dirname(sys.prefix), '..')))
+                configfile = os.path.join(prefixdir, 'etc', 'trytond.conf')
+                if not os.path.isfile(configfile):
+                    configdir = os.path.abspath(os.path.normpath(os.path.join(
+                        os.path.dirname(__file__), '..')))
+                    configfile = os.path.join(configdir, 'etc', 'trytond.conf')
+                if not os.path.isfile(configfile):
+                    configfile = None
 
         self.configfile = configfile
         if not self.configfile:
